@@ -20,9 +20,8 @@
 #' for action sequences. If \code{dist_type = "oss_both"}, both action sequences and
 #' timestamp sequences are used to compute a time-weighted oss. 
 #'   
-#' The number of
-#' features to be extracted \code{K} can be selected by cross-validation using
-#' \code{\link{chooseK_mds}}.
+#' The number of features to be extracted \code{K} can be selected by cross-validation 
+#' using \code{\link{chooseK_mds}}.
 #'
 #' @family feature extraction methods
 #' @param seqs a \code{"\link{proc}"} object or a square matrix. If a squared matrix is 
@@ -40,7 +39,6 @@
 #'   in the large data algorithm. See 'Details' and \code{\link{seq2feature_mds_large}}.
 #' @param return_dist logical. If \code{TRUE}, the dissimilarity matrix will be
 #'   returned. Default is \code{FALSE}.
-#' @param seed random seed.
 #' @param L_set length of ngrams considered
 #' @return \code{seq2feature_mds} returns a list containing 
 #'   \item{theta}{a numeric matrix giving the \code{K} extracted features or principal
@@ -53,15 +51,17 @@
 #'   \emph{Modeling Decisions for Artificial Intelligence}, (pp. 134-145). Springer Berlin Heidelberg.
 #' @references Paradis, E. (2018). Multidimensional scaling with very large datasets. \emph{
 #'   Journal of Computational and Graphical Statistics}, 27(4), 935-939.
+#' @references Tang, X., Wang, Z., He, Q., Liu, J., and Ying, Z. (2020) Latent Feature Extraction for 
+#'   Process Data via Multidimensional Scaling. \emph{Psychometrika}, 85, 378-397.
 #' @examples
 #' n <- 50
+#' set.seed(12345)
 #' seqs <- seq_gen(n)
 #' theta <- seq2feature_mds(seqs, 5)$theta
 #' @export
 seq2feature_mds <- function(seqs = NULL, K = 2, method = "auto", dist_type = "oss_action", 
                             pca = TRUE, subset_size = 100, subset_method = "random", n_cand = 10, 
-                            return_dist = FALSE, seed = 12345, L_set = 1:3) {
-  set.seed(seed)
+                            return_dist = FALSE, L_set = 1:3) {
   dist_ready <- FALSE
   if (is.null(seqs)) 
     stop("Either response processes or their dissimilarity matrix should be provided!\n")
@@ -106,7 +106,7 @@ seq2feature_mds <- function(seqs = NULL, K = 2, method = "auto", dist_type = "os
     if (subset_size > n) stop("Subset size is larger than the sample size!\n")
     theta <- seq2feature_mds_large(seqs = seqs, K = K, dist_type = dist_type, 
                           subset_size = subset_size, subset_method = subset_method, 
-                          n_cand = n_cand, pca = pca, seed = seed, L_set = L_set)
+                          n_cand = n_cand, pca = pca, L_set = L_set)
   }
   
   if (return_dist & dist_ready) 
@@ -143,6 +143,7 @@ seq2feature_mds <- function(seqs = NULL, K = 2, method = "auto", dist_type = "os
 #'   \emph{Modeling Decisions for Artificial Intelligence}, (pp. 134-145). Springer Berlin Heidelberg.
 #' @examples 
 #' n <- 50
+#' set.seed(12345)
 #' seqs <- seq_gen(n)
 #' K_res <- chooseK_mds(seqs, 5:10, return_dist=TRUE)
 #' theta <- seq2feature_mds(K_res$dist_mat, K_res$K)$theta
@@ -150,8 +151,7 @@ seq2feature_mds <- function(seqs = NULL, K = 2, method = "auto", dist_type = "os
 #' @export 
 chooseK_mds <- function(seqs=NULL, K_cand, dist_type="oss_action", n_fold=5, 
                         max_epoch=100, step_size=0.01, tot=1e-6, return_dist=FALSE,
-                        seed = 12345, L_set = 1:3) {
-  set.seed(seed)
+                        L_set = 1:3) {
   if (is.null(seqs)) 
     stop("Either response processes or their dissimilarity matrix should be provided!\n")
   if (is.matrix(seqs)) {
@@ -233,7 +233,7 @@ chooseK_mds <- function(seqs=NULL, K_cand, dist_type="oss_action", n_fold=5,
 #' @export
 seq2feature_mds_large <- function(seqs, K, dist_type = "oss_action", subset_size, 
                                   subset_method = "random", n_cand = 10, 
-                                  pca = TRUE, seed = 12345, L_set = 1:3) {
+                                  pca = TRUE, L_set = 1:3) {
   n <- length(seqs$action_seqs)
   theta <- matrix(0, n, K)
   
@@ -390,7 +390,6 @@ seq2feature_mds_large <- function(seqs, K, dist_type = "oss_action", subset_size
 #' @param tot the accuracy tolerance for determining convergence.
 #' @param return_dist logical. If \code{TRUE}, the dissimilarity matrix will be
 #'   returned. Default is \code{FALSE}.
-#' @param seed random seed.
 #' @param L_set length of ngrams considered.
 #' @return \code{seq2feature_mds_stochastic} returns a list containing 
 #'   \item{theta}{a numeric matrix giving the \code{K} extracted features or principal
@@ -400,8 +399,7 @@ seq2feature_mds_large <- function(seqs, K, dist_type = "oss_action", subset_size
 #' @export
 seq2feature_mds_stochastic <- function(seqs = NULL, K = 2, dist_type = "oss_action", 
                                        max_epoch=100, step_size=0.01, pca=TRUE, 
-                                       tot=1e-6, return_dist=FALSE, seed=12345, L_set=1:3) {
-  set.seed(seed)
+                                       tot=1e-6, return_dist=FALSE, L_set=1:3) {
   if (is.null(seqs)) 
     stop("Either response processes or their dissimilarity matrix should be provided!\n")
   if (is.matrix(seqs)) {
@@ -431,7 +429,7 @@ seq2feature_mds_stochastic <- function(seqs = NULL, K = 2, dist_type = "oss_acti
   theta <- cmdscale(dist_mat, K)
   
   # mds
-  mds_res <- MDS(dist_mat, theta, max_epoch, step_size, tot, seed)
+  mds_res <- MDS(dist_mat, theta, max_epoch, step_size, tot)
   if (!mds_res$convergence) warning("MDS does not converge!")
   if (pca) theta <- prcomp(theta, center=TRUE, scale=FALSE)$x
   
@@ -481,9 +479,6 @@ seq2feature_mds_stochastic <- function(seqs = NULL, K = 2, dist_type = "oss_acti
 #'   training, validation and test sets for training autoencoder.
 #' @param pca logical. If TRUE, the principal components of features are
 #'   returned. Default is TRUE.
-#' @param gpu logical. If TRUE, use gpu for training when available. Default is FALSE.
-#' @param parallel logical. If TRUE, allow cpu parallel computing. Default is FALSE.
-#' @param seed random seed.
 #' @param verbose logical. If TRUE, training progress is printed.
 #' @param return_theta logical. If TRUE, extracted features are returned.
 #' @return \code{seq2feature_seq2seq} returns a list containing
@@ -492,42 +487,48 @@ seq2feature_mds_stochastic <- function(seqs = NULL, K = 2, dist_type = "oss_acti
 #'   \item{valid_loss}{a vector of length \code{n_epoch} recording the trace of validation losses.}
 #'   \item{test_loss}{a vector of length \code{n_epoch} recording the trace of test losses. Exists only if \code{samples_test} is not \code{NULL}.}
 #' @seealso \code{\link{chooseK_seq2seq}} for choosing \code{K} through cross-validation.
+#' @references Tang, X., Wang, Z., Liu, J., and Ying, Z. (2020) An exploratory analysis of the latent 
+#'   structure of process data via action sequence autoencoders. \emph{British Journal of 
+#'   Mathematical and Statistical Psychology}. 74(1), 1-33.
 #' @examples
 #' \donttest{ 
-#' n <- 50
-#' data(cc_data)
-#' samples <- sample(1:length(cc_data$seqs$time_seqs), n)
-#' seqs <- sub_seqs(cc_data$seqs, samples)
+#' if (!system("python -c 'import tensorflow as tf'", ignore.stdout = TRUE, ignore.stderr= TRUE)) {
+#'   n <- 50
+#'   data(cc_data)
+#'   samples <- sample(1:length(cc_data$seqs$time_seqs), n)
+#'   seqs <- sub_seqs(cc_data$seqs, samples)
 #' 
-#' # action sequence autoencoder
-#' K_res <- chooseK_seq2seq(seqs=seqs, ae_type="action", K_cand=c(5, 10), 
-#'                          n_epoch=5, n_fold=2, valid_prop=0.2)
-#' seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="action", K=K_res$K, 
-#'                        n_epoch=5, samples_train=1:40, samples_valid=41:50)
-#' theta <- seq2seq_res$theta
+#'   # action sequence autoencoder
+#'   K_res <- chooseK_seq2seq(seqs=seqs, ae_type="action", K_cand=c(5, 10), 
+#'                            n_epoch=5, n_fold=2, valid_prop=0.2)
+#'   seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="action", K=K_res$K, 
+#'                          n_epoch=5, samples_train=1:40, samples_valid=41:50)
+#'   theta <- seq2seq_res$theta
 #' 
-#' # time sequence autoencoder
-#' K_res <- chooseK_seq2seq(seqs=seqs, ae_type="time", K_cand=c(5, 10), 
-#'                          n_epoch=5, n_fold=2, valid_prop=0.2)
-#' seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="time", K=K_res$K, 
-#'                        n_epoch=5, samples_train=1:40, samples_valid=41:50)
-#' theta <- seq2seq_res$theta
+#'   # time sequence autoencoder
+#'   K_res <- chooseK_seq2seq(seqs=seqs, ae_type="time", K_cand=c(5, 10), 
+#'                            n_epoch=5, n_fold=2, valid_prop=0.2)
+#'   seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="time", K=K_res$K, 
+#'                          n_epoch=5, samples_train=1:40, samples_valid=41:50)
+#'   theta <- seq2seq_res$theta
 #' 
-#' # action and time sequence autoencoder
-#' K_res <- chooseK_seq2seq(seqs=seqs, ae_type="both", K_cand=c(5, 10), 
-#'                          n_epoch=5, n_fold=2, valid_prop=0.2)
-#' seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="both", K=K_res$K, 
-#'                        n_epoch=5, samples_train=1:40, samples_valid=41:50)
-#' theta <- seq2seq_res$theta
-#' plot(seq2seq_res$train_loss, col="blue", type="l")
-#' lines(seq2seq_res$valid_loss, col="red")
+#'   # action and time sequence autoencoder
+#'   K_res <- chooseK_seq2seq(seqs=seqs, ae_type="both", K_cand=c(5, 10), 
+#'                            n_epoch=5, n_fold=2, valid_prop=0.2)
+#'   seq2seq_res <- seq2feature_seq2seq(seqs=seqs, ae_type="both", K=K_res$K, 
+#'                          n_epoch=5, samples_train=1:40, samples_valid=41:50)
+#'   theta <- seq2seq_res$theta
+#'   plot(seq2seq_res$train_loss, col="blue", type="l")
+#'   lines(seq2seq_res$valid_loss, col="red")
+#' }
 #' }
 #' @export
 seq2feature_seq2seq <- function(seqs, ae_type="action", K, rnn_type="lstm", n_epoch=50, 
                                 method="last", step_size=0.0001, optimizer_name="adam", 
                                 cumulative=FALSE, log=TRUE, weights=c(1.0, 0.5), 
                                 samples_train, samples_valid, samples_test=NULL, pca=TRUE, 
-                                gpu=FALSE, parallel=FALSE, seed=12345, verbose=TRUE, 
+                                #gpu=FALSE, parallel=FALSE, seed=12345, 
+                                verbose=TRUE, 
                                 return_theta=TRUE) {
   if (ae_type=="action")
     res <- aseq2feature_seq2seq(aseqs=seqs$action_seqs, 
@@ -541,9 +542,9 @@ seq2feature_seq2seq <- function(seqs, ae_type="action", K, rnn_type="lstm", n_ep
                                 samples_valid = samples_valid,
                                 samples_test = samples_test,
                                 pca = pca,
-                                gpu = gpu,
-                                parallel = parallel,
-                                seed = seed,
+                                #gpu = gpu,
+                                #parallel = parallel,
+                                #seed = seed,
                                 verbose = verbose,
                                 return_theta = TRUE)
   else if (ae_type=="time")
@@ -560,9 +561,9 @@ seq2feature_seq2seq <- function(seqs, ae_type="action", K, rnn_type="lstm", n_ep
                                 samples_valid = samples_valid,
                                 samples_test = samples_test,
                                 pca = pca,
-                                gpu = gpu,
-                                parallel = parallel,
-                                seed = seed,
+                                #gpu = gpu,
+                                #parallel = parallel,
+                                #seed = seed,
                                 verbose = verbose,
                                 return_theta = TRUE)
   else if (ae_type=="both")
@@ -580,9 +581,9 @@ seq2feature_seq2seq <- function(seqs, ae_type="action", K, rnn_type="lstm", n_ep
                                  samples_valid = samples_valid,
                                  samples_test = samples_test,
                                  pca = pca,
-                                 gpu = gpu,
-                                 parallel = parallel,
-                                 seed = seed,
+                                 #gpu = gpu,
+                                 #parallel = parallel,
+                                 #seed = seed,
                                  verbose = verbose,
                                  return_theta = TRUE)
   else stop("ae_type has to be 'action', time', or 'both'!\n")
@@ -608,9 +609,9 @@ seq2feature_seq2seq <- function(seqs, ae_type="action", K, rnn_type="lstm", n_ep
 chooseK_seq2seq <- function(seqs, ae_type, K_cand, rnn_type="lstm", n_epoch=50, method="last", 
                             step_size=0.0001, optimizer_name="adam", n_fold=5, 
                             cumulative = FALSE, log = TRUE, weights = c(1., .5), 
-                            valid_prop=0.1, gpu = FALSE, parallel=FALSE, seed=12345, 
+                            valid_prop=0.1, 
+                            #gpu = FALSE, parallel=FALSE, seed=12345, 
                             verbose=TRUE) {
-  set.seed(seed)
   n_K <- length(K_cand)
   n_seq <- length(seqs$action_seqs)
   folds <- sample(1:n_fold, n_seq, replace=TRUE)
@@ -640,9 +641,9 @@ chooseK_seq2seq <- function(seqs, ae_type, K_cand, rnn_type="lstm", n_epoch=50,
                                          samples_valid = index_valid, 
                                          samples_test = index_test, 
                                          pca = FALSE, 
-                                         gpu = gpu, 
-                                         parallel = parallel, 
-                                         seed = seed,
+                                         #gpu = gpu, 
+                                         #parallel = parallel, 
+                                         #seed = seed,
                                          verbose = verbose, 
                                          return_theta = FALSE)
       
